==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/ToolChain/install_24_TTC_MUTEX.sh <==
#!/bin/bash
#
#
#  Install script for generic inter task communication support 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="500_ttc_mutex"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

MAIN_OBJS += ttc_mutex.o

ifdef EXTENSION_300_scheduler_free_rtos
  
  # activate certain features of FreeRTOS to support queuing
  COMPILE_OPTS += -DconfigUSE_MUTEXES=1
  COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES=1
endif

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Scheduler independent support for inter task communication via mutexes"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*

ArchitectureSupportAvailable=""

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# try tp activate at least one low-level driver
if [ -e "\$Dir_ExtensionsActive/makefile.300_scheduler_free_rtos" ]; then

  # check if file already exists to avoid endless loop
  if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex_freertos" ]; then
    activate.500_ttc_mutex_freertos.sh QUIET "\$0"
  fi
else
  if [ -e "\$Dir_ExtensionsActive/makefile.190_cpu_cortexm3" ]; then
    # check if file already exists to avoid endless loop
    if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex_cortexm3" ]; then
      activate.500_ttc_mutex_cortexm3.sh QUIET "\$0"
    fi
  fi
fi

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  Name="${INSTALLPATH}_freertos"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

# activate certain features of FreeRTOS to support queuing
COMPILE_OPTS += -DconfigUSE_MUTEXES=1
COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES=1

MAIN_OBJS += freertos_mutex.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "mutex implementation based on FreeRTOS"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*


# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex" ]; then
  activate.500_ttc_mutex.sh           QUIET "\$0"
fi
# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.300_scheduler_free_rtos" ]; then
  activate.300_scheduler_free_rtos.sh QUIET "\$0"
fi

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  Name="${INSTALLPATH}_cortexm3"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name 

MAIN_OBJS += cm3_mutex.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{ create activate script
  createActivateScriptHead $File "$0" "Mutex low-level driver for CortexM3 architecture"
  cat <<END_OF_ACTIVATE >>$File
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*

activate.190_cpu_cortexm3.sh QUIET "\$0"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex" ]; then
  activate.500_ttc_mutex.sh           QUIET "\$0"
fi

END_OF_ACTIVATE
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $Name"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/ToolChain/install_24_TTC_MUTEX.sh <==
#!/bin/bash
#
#
#  Install script for generic inter task communication support 
#
#  Initial Script written by Gregor Rebel 2010-2012.
# 
#  Published under GNU Lesser General Public License
#  Check LEGAL.txt for details.
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh
checkUserRoot "$1" "$2"

StartPath="`pwd`"
INSTALLPATH="500_ttc_mutex"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="$INSTALLPATH"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>$ExtensionMakeFile # variable set by createExtensionMakefileHead() 

MAIN_OBJS += ttc_mutex.o

ifdef EXTENSION_300_scheduler_free_rtos
  
  # activate certain features of FreeRTOS to support queuing
  COMPILE_OPTS += -DconfigUSE_MUTEXES=1
  COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES=1
endif

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  createActivateScriptHead $Name ../extensions/ "$0" "Scheduler independent support for inter task communication via mutexes" #{
  cat <<END_OF_ACTIVATE >>$ActivateScriptFile
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*

ArchitectureSupportAvailable=""

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# try tp activate at least one low-level driver
if [ -e "\$Dir_ExtensionsActive/makefile.300_scheduler_free_rtos" ]; then

  # check if file already exists to avoid endless loop
  if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex_freertos" ]; then
    activate.500_ttc_mutex_freertos.sh QUIET "\$0"
  fi
else
  if [ -e "\$Dir_ExtensionsActive/makefile.190_cpu_cortexm3" ]; then
    # check if file already exists to avoid endless loop
    if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex_cortexm3" ]; then
      activate.500_ttc_mutex_cortexm3.sh QUIET "\$0"
    fi
  fi
fi

END_OF_ACTIVATE
  createActivateScriptTail $Name ../extensions/
  #}

  Name="${INSTALLPATH}_freertos"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>$ExtensionMakeFile # variable set by createExtensionMakefileHead() 

# activate certain features of FreeRTOS to support queuing
COMPILE_OPTS += -DconfigUSE_MUTEXES=1
COMPILE_OPTS += -DconfigUSE_COUNTING_SEMAPHORES=1

MAIN_OBJS += freertos_mutex.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  createActivateScriptHead $Name ../extensions/ "$0" "mutex implementation based on FreeRTOS" #{
  cat <<END_OF_ACTIVATE >>$ActivateScriptFile
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*


# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex" ]; then
  activate.500_ttc_mutex.sh           QUIET "\$0"
fi
# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.300_scheduler_free_rtos" ]; then
  activate.300_scheduler_free_rtos.sh QUIET "\$0"
fi

END_OF_ACTIVATE
  createActivateScriptTail $Name ../extensions/
  #}

  Name="${INSTALLPATH}_cortexm3"
  createExtensionMakefileHead ${Name}      #{ create makefile
  cat <<END_OF_MAKEFILE >>$ExtensionMakeFile # variable set by createExtensionMakefileHead() 

MAIN_OBJS += cm3_mutex.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  createActivateScriptHead $Name ../extensions/ "$0" "Mutex low-level driver for CortexM3 architecture" #{
  cat <<END_OF_ACTIVATE >>$ActivateScriptFile
# available variables (-> scripts/installFuncs.sh:createActivateScriptHead())
#
# Paths to certain directories in current project folder
#   \$Dir_Extensions        -> extensions/
#   \$Dir_ExtensionsLocal   -> extensions.local/
#   \$Dir_ExtensionsActive  -> extensions.active/
#   \$Dir_Additionals       -> additionals/

# remove activated variants of same type
rm 2>/dev/null \$Dir_ExtensionsActive/makefile.${INSTALLPATH}_*

activate.190_cpu_cortexm3.sh QUIET "\$0"

# create links into extensions.active/
createLink "\$Dir_Extensions/makefile.$Name" "\$Dir_ExtensionsActive/makefile.$Name" '' QUIET

# check if file already exists to avoid endless loop
if [ ! -e "\$Dir_ExtensionsActive/makefile.500_ttc_mutex" ]; then
  activate.500_ttc_mutex.sh           QUIET "\$0"
fi

END_OF_ACTIVATE
  createActivateScriptTail $Name ../extensions/
  #}

  echo "Installed successfully: $Name"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

cd "$StartPath"
applyTargetUserAndGroup "$INSTALLPATH"

exit 0
